summaryrefslogtreecommitdiff
path: root/host/lib/include/util_misc.h
diff options
context:
space:
mode:
Diffstat (limited to 'host/lib/include/util_misc.h')
-rw-r--r--host/lib/include/util_misc.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/host/lib/include/util_misc.h b/host/lib/include/util_misc.h
index 0a6ed4c4..d5a08fe3 100644
--- a/host/lib/include/util_misc.h
+++ b/host/lib/include/util_misc.h
@@ -8,11 +8,15 @@
#ifndef VBOOT_REFERENCE_UTIL_MISC_H_
#define VBOOT_REFERENCE_UTIL_MISC_H_
+#include "host_key.h"
#include "vboot_struct.h"
struct rsa_st;
-/* Prints the sha1sum of the given VbPublicKey to stdout. */
-void PrintPubKeySha1Sum(VbPublicKey* key);
+/* Prints the sha1sum of a VbPublicKey to stdout. */
+void PrintPubKeySha1Sum(VbPublicKey *key);
+
+/* Prints the sha1sum of a VbPrivateKey to stdout. */
+void PrintPrivKeySha1Sum(VbPrivateKey *key);
/*
* Our packed RSBPublicKey buffer (historically in files ending with ".keyb",